@@ -1,7 +1,7 @@
 # -*- mode: Perl -*-
 package MRTG_lib;
 ###################################################################
-# MRTG 2.17.2  Support library MRTG_lib.pm
+# MRTG 2.17.3  Support library MRTG_lib.pm
 ###################################################################
 # Created by Tobias Oetiker <tobi@oetiker.ch>
 #            and Dave Rand <dlr@bungi.com>
@@ -782,6 +782,7 @@ sub cfgcheck ($$$$;$) {
     debug('dir', "imagehtml = $$cfg{imagehtml}");
 
     $SNMP_util::CacheFile = "$$cfg{'logdir'}oid-mib-cache.txt";
+    $Net_SNMP_util::CacheFile = "$$cfg{'logdir'}oid-mib-cache.txt";
 
     if (defined $$cfg{loadmibs}) {
         my($mibFile);
@@ -1112,8 +1113,7 @@ sub cfgcheck ($$$$;$) {
         }
         if (defined $$rcfg{'options'}{'pngdate'}{$rou}) {
             $$rcfg{'timestrpos'}{$rou} = 'RU';
-            $$rcfg{'timestrfmt'}{$rou} = "%Y-%m-%d %H:%M %Z";
-
+            $$rcfg{'timestrfmt'}{$rou} = $$rcfg{'timezone'}{$rou} ? "%Y-%m-%d %H:%M %Z" : "%Y-%m-%d %H:%M";
             delete $$rcfg{'options'}{'pntdate'}{$rou}
         }
         if (! defined $$rcfg{'timestrpos'}{$rou}) {
