@@ -1,5 +1,5 @@
 /*
- MRTG 2.17.2  -- Rateup
+ MRTG 2.17.3  -- Rateup
  *********************
 
  Rateup is a fast add-on to the great MRTG Traffic monitor.  It makes
@@ -83,7 +83,7 @@
 #include <gd.h>
 #include <gdfonts.h>
 
-char *VERSION = "2.17.2";
+char *VERSION = "2.17.3";
 char *program, *router, *routerpath;
 int histvalid;
 
@@ -115,7 +115,6 @@ char **short_si = short_si_def;
 char *longup = NULL;
 char *shortup = NULL;
 char *pngtitle = NULL;
-char *pngdate = NULL;
 char *rtimezone = NULL;
 char weekformat = 'V';		/* strftime() fmt char for week #  */
 
@@ -302,7 +301,7 @@ image (file, maxvi, maxvo, maxx, maxy, xscale, yscale, growright, step, bits,
   char currdatetimestr[256];
   time_t currdatetime;
   int currdatetimepos_x, currdatetimepos_y;
-
+  
 #define NO_TIMESTAMPSTR (0)
 #define LU_CORNER (1)
 #define RU_CORNER (2)
@@ -488,13 +487,21 @@ image (file, maxvi, maxvo, maxx, maxy, xscale, yscale, growright, step, bits,
         {
           short_si_out = kMG;
           kMGnumber = 0;
-	  short_si[0] = kMG;
           while ((short_si_out = strchr (short_si_out, ',')) != NULL)
 	    {
-	      short_si_out[0] = '\0';
 	      short_si_out++;
-              short_si[++kMGnumber] = short_si_out;
+              kMGnumber++;
 	    }
+          short_si = calloc(kMGnumber + 1, sizeof(*short_si));
+          short_si_out = kMG;
+          for (kMGnumber = 0; ; kMGnumber++)
+            {
+              short_si[kMGnumber] = short_si_out;
+             short_si_out = strchr(short_si_out, ',');
+              if (short_si_out == NULL) break;
+              short_si_out[0] = '\0';
+              short_si_out++;
+            }
         }
      }
   
@@ -1108,9 +1115,9 @@ image (file, maxvi, maxvo, maxx, maxy, xscale, yscale, growright, step, bits,
 		     currdatetimepos_x, currdatetimepos_y,
 		     (unsigned char *)currdatetimestr, i_grid);
     }
-  file_tmp[0]=0;
-  strncat(file_tmp,file,1000);
-  strncat(file_tmp,".tmp",1000);
+
+  snprintf(file_tmp,1000,"%s.tmp_%lu",file,(unsigned long)getpid());
+
   if ((fo = fopen (file_tmp, "wb")) == NULL)
     {
       perror (program);
@@ -1125,6 +1132,9 @@ image (file, maxvi, maxvo, maxx, maxy, xscale, yscale, growright, step, bits,
   gdImageDestroy (brush_outp);
   free (lhist);
   free (graph_label);
+  if (kMG)
+    free(short_si);
+
 
 #ifdef WIN32
   /* got to remove the target under win32
@@ -1392,7 +1402,7 @@ update (in, out, abs_max, absupdate)
 	       (unsigned long) now);
       return;
     }
-  sprintf (buf, "%s.tmp", router);
+  sprintf (buf, "%s.tmp_%lu", router,(unsigned long)getpid());
   sprintf (buf1, "%s.log", router);
   sprintf (buf2, "%s.old", router);
   if ((lhist = calloc (1, sizeof (struct HISTORY) * (MAX_HISTORY + 1))) ==
@@ -1792,6 +1802,7 @@ readparam (char const *file)
   if (!(cbuf = fread (buff, 1, LENGTH_OF_BUFF, fp)))
     {
       fprintf (stderr, "%s, %s ERROR: Parameters file empty\n", bufftime, program);
+      fclose(fp);
       return (1);
     }
   fclose (fp);
